/**********************************************************************
zyGrib: meteorological GRIB file viewer
Copyright (C) 2008-2010 - Jacques Zaninetti - http://www.zygrib.org

This program is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program.  If not, see <http://www.gnu.org/licenses/>.
***********************************************************************/

#include "Util.h"
#include "DataPointInfo.h"

DataPointInfo::DataPointInfo ( 
					GriddedReader *reader, 
					double x, double y, time_t  date )
	{
		this->x = x;
		this->y = y;
		this->date = date;
		this->reader = reader;

	vx = reader==NULL ? GRIB_NOTDEF
			: reader->getDateInterpolatedValue (DataCode(GRB_WIND_VX,LV_ABOV_GND,10), x,y,date);
	vy = reader==NULL ? GRIB_NOTDEF
			: reader->getDateInterpolatedValue (DataCode(GRB_WIND_VY,LV_ABOV_GND,10), x,y,date);
	pressure = reader==NULL ? GRIB_NOTDEF
			: reader->getDateInterpolatedValue (DataCode(GRB_PRESSURE,LV_MSL,0), x,y,date);
	temp = reader==NULL ? GRIB_NOTDEF
			: reader->getDateInterpolatedValue (DataCode(GRB_TEMP,LV_ABOV_GND,2), x,y,date);
	tempPot = reader==NULL ? GRIB_NOTDEF
			: reader->getDateInterpolatedValue (DataCode(GRB_TEMP_POT,LV_SIGMA,9950), x,y,date);
	tempMin = reader==NULL ? GRIB_NOTDEF
			: reader->getDateInterpolatedValue (DataCode(GRB_TMIN,LV_ABOV_GND,2), x,y,date);
	tempMax = reader==NULL ? GRIB_NOTDEF
			: reader->getDateInterpolatedValue (DataCode(GRB_TMAX,LV_ABOV_GND,2), x,y,date);
	rain    = reader==NULL ? GRIB_NOTDEF
			: reader->getDateInterpolatedValue (DataCode(GRB_PRECIP_TOT,LV_GND_SURF,0), x,y,date);
	cloud   = reader==NULL ? GRIB_NOTDEF
			: reader->getDateInterpolatedValue (DataCode(GRB_CLOUD_TOT,LV_ATMOS_ALL,0), x,y,date);
	humidRel = reader==NULL ? GRIB_NOTDEF
			: reader->getDateInterpolatedValue (DataCode(GRB_HUMID_REL,LV_ABOV_GND,2), x,y,date);
	humidSpec = reader==NULL ? GRIB_NOTDEF
			: reader->getDateInterpolatedValue (DataCode(GRB_HUMID_SPEC,LV_ABOV_GND,2), x,y,date);
	dewPoint = reader==NULL ? GRIB_NOTDEF
			: reader->getDateInterpolatedValue (DataCode(GRB_DEWPOINT,LV_ABOV_GND,2), x,y,date);
	isotherm0HGT = reader==NULL ? GRIB_NOTDEF
			: reader->getDateInterpolatedValue (DataCode(GRB_GEOPOT_HGT,LV_ISOTHERM0,0), x,y,date);
	snowDepth    = reader==NULL ? GRIB_NOTDEF
			: reader->getDateInterpolatedValue (DataCode(GRB_SNOW_DEPTH,LV_GND_SURF,0), x,y,date);
	snowCateg    = reader==NULL ? GRIB_NOTDEF
			: reader->getDateInterpolatedValue (DataCode(GRB_SNOW_CATEG,LV_GND_SURF,0), x,y,date);
	frzRainCateg = reader==NULL ? GRIB_NOTDEF
			: reader->getDateInterpolatedValue (DataCode(GRB_FRZRAIN_CATEG,LV_GND_SURF,0), x,y,date);
	CAPEsfc = reader==NULL ? GRIB_NOTDEF
			: reader->getDateInterpolatedValue (DataCode(GRB_CAPE,LV_GND_SURF,0), x,y,date);

	//-------------------------------------------------------------
	double SH, T;
	int P, i;
	for (i=0; i<4; i++)
	{
		P = GEOPOThgt(i);	// 850 700 500 300
		SH = reader->getDateInterpolatedValue (DataCode(GRB_HUMID_SPEC,LV_ISOBARIC,P), x,y,date);
		T = reader->getDateInterpolatedValue (DataCode(GRB_TEMP,LV_ISOBARIC,P), x,y,date);
		hthetae [i] = DataRecordAbstract::computeThetaE (T,P,SH);
		htemp [i] = T;
		hgeopot [i] = reader->getDateInterpolatedValue (DataCode(GRB_GEOPOT_HGT,LV_ISOBARIC,P), x,y,date);
		hvx [i] = reader->getDateInterpolatedValue (DataCode(GRB_WIND_VX,LV_ISOBARIC,P), x,y,date);
		hvy [i] = reader->getDateInterpolatedValue (DataCode(GRB_WIND_VY,LV_ISOBARIC,P), x,y,date);
	}
	
	hasAltitudeData = reader==NULL ? false : reader->hasAltitudeData();
}

